# OsxHarvey

The *Big White Rabbit* OsxHarvey is a small tool/Wifi-Sniffer to grab all the data.

Being a rabbit, Harvey hops from wifi-channel to wifi-channel to make sure he doesn't 
miss anything.

Harvey is intended to be used by security professionals for LEGAL purposes.

## This package is in pre-Alpha and therefore still under construction